LoadPackage("atlasrep");
LoadPackage("io");

checkD := function(gr, c)
  local sg, x, y;
  x := Representative(c);
  for y in c do
    if not (x*y)^2 = (y*x)^2 then 
      sg := Subgroup(gr, [x,y]);
      if IsConjugate(sg, x, y) = false then
        return [x,y];
      fi;
    fi;
  od;
  return fail;
end;

x := [];
g := [];
n := 0;

name := "2F4(2)'.2";

LogTo(Concatenation(name, ".log"));

gr := AtlasGroup(name);
cc := ConjugacyClasses(gr);
ct := CharacterTable(name);

Print("Group: ", name, "\n");

ns := ClassPositionsOfNormalSubgroups(ct);
cl := Filtered([1..NrConjugacyClasses(ct)], x->not x in ns[2]);
Print("Conjugacy classes to study:\n");
for x in cl do
  Print(x, "\n");
od;
Print("==\n");

# For this group it is not possible to identify the conjugacy classes 
bg := BaseOfGroup(gr);
Print("Base of Group: ", bg, "\n--\n");

f := IO_File(Concatenation(name, ".rec"), "w");
IO_WriteLine(f,"### The format for classinfo is [ r, s, order, comment ]");
IO_WriteLine(f,"data := rec(");
IO_WriteLine(f,"  base := ", bg, ",");
IO_WriteLine(f,"  group := \"", name, "\",");
IO_WriteLine(f,"  comments := \"\",");
IO_WriteLine(f,"  classinfo := [");

rem := [];

for n in cl do
  c := cc[n];
  g := Representative(c);
  Print("Representative of order: ", Order(g), "\n");
  Print("Size: ", SizesConjugacyClasses(ct)[n], "\n");
  Print("Size of the centralizer: ", SizesCentralizers(ct)[n], "\n");
  Print("Class: ", n, "\n");
  rs := checkD(gr, c); 
  if not rs = fail then
  	Print("r:=", OnTuples(bg, rs[1]), ";\n");
  	Print("s:=", OnTuples(bg, rs[2]), ";\n");
    IO_WriteLine(f, "    [ ", OnTuples(bg, rs[1]), ", ", OnTuples(bg, rs[2]), ", ", Order(g), ", \"D\" ],");
    Print("Removed: ", n, "\n");
    Add(rem, n);
    Print("==\n");
  else
    Print("Not of type D!\n");
    Print("==\n");
  fi;
od;

a := cl; 
b := rem;

Print("Summary:\n");
Print("To study: ", a, "\n");
Print("Removed: ", b, "\n");
Print("Not of type D: ", Difference(a,b), "\n");

IO_WriteLine(f, "  ]");
IO_WriteLine(f, ");");
IO_Flush(f);
IO_Close(f);

